# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: queueservice.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
  name='queueservice.proto',
  package='streaming',
  syntax='proto3',
  serialized_options=_b('Z\023pkg/streaming/types'),
  serialized_pb=_b(
    '\n\x12queueservice.proto\x12\tstreaming\"\x9e\x01\n\x0e\x44\x61taFrameProto\x12\r\n\x05index\x18\x01 \x01(\x04\x12\x31\n\x04tags\x18\x02 \x03(\x0b\x32#.streaming.DataFrameProto.TagsEntry\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x0f\n\x07message\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\">\n\x12\x44\x61taFrameListProto\x12(\n\x05index\x18\x01 \x03(\x0b\x32\x19.streaming.DataFrameProto\"\x84\x01\n\x0f\x41ttributesProto\x12>\n\nattributes\x18\x01 \x03(\x0b\x32*.streaming.AttributesProto.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x15Z\x13pkg/streaming/typesb\x06proto3')
)

_DATAFRAMEPROTO_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='streaming.DataFrameProto.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='streaming.DataFrameProto.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='streaming.DataFrameProto.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=192,
)

_DATAFRAMEPROTO = _descriptor.Descriptor(
  name='DataFrameProto',
  full_name='streaming.DataFrameProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='streaming.DataFrameProto.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='streaming.DataFrameProto.tags', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='streaming.DataFrameProto.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='streaming.DataFrameProto.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATAFRAMEPROTO_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=192,
)

_DATAFRAMELISTPROTO = _descriptor.Descriptor(
  name='DataFrameListProto',
  full_name='streaming.DataFrameListProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='streaming.DataFrameListProto.index', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=256,
)

_ATTRIBUTESPROTO_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='streaming.AttributesProto.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='streaming.AttributesProto.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='streaming.AttributesProto.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=391,
)

_ATTRIBUTESPROTO = _descriptor.Descriptor(
  name='AttributesProto',
  full_name='streaming.AttributesProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='streaming.AttributesProto.attributes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ATTRIBUTESPROTO_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=391,
)

_DATAFRAMEPROTO_TAGSENTRY.containing_type = _DATAFRAMEPROTO
_DATAFRAMEPROTO.fields_by_name['tags'].message_type = _DATAFRAMEPROTO_TAGSENTRY
_DATAFRAMELISTPROTO.fields_by_name['index'].message_type = _DATAFRAMEPROTO
_ATTRIBUTESPROTO_ATTRIBUTESENTRY.containing_type = _ATTRIBUTESPROTO
_ATTRIBUTESPROTO.fields_by_name['attributes'].message_type = _ATTRIBUTESPROTO_ATTRIBUTESENTRY
DESCRIPTOR.message_types_by_name['DataFrameProto'] = _DATAFRAMEPROTO
DESCRIPTOR.message_types_by_name['DataFrameListProto'] = _DATAFRAMELISTPROTO
DESCRIPTOR.message_types_by_name['AttributesProto'] = _ATTRIBUTESPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataFrameProto = _reflection.GeneratedProtocolMessageType('DataFrameProto', (_message.Message,), dict(

  TagsEntry=_reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), dict(
    DESCRIPTOR=_DATAFRAMEPROTO_TAGSENTRY,
    __module__='queueservice_pb2'
    # @@protoc_insertion_point(class_scope:streaming.DataFrameProto.TagsEntry)
  ))
  ,
  DESCRIPTOR=_DATAFRAMEPROTO,
  __module__='queueservice_pb2'
  # @@protoc_insertion_point(class_scope:streaming.DataFrameProto)
))
_sym_db.RegisterMessage(DataFrameProto)
_sym_db.RegisterMessage(DataFrameProto.TagsEntry)

DataFrameListProto = _reflection.GeneratedProtocolMessageType('DataFrameListProto', (_message.Message,), dict(
  DESCRIPTOR=_DATAFRAMELISTPROTO,
  __module__='queueservice_pb2'
  # @@protoc_insertion_point(class_scope:streaming.DataFrameListProto)
))
_sym_db.RegisterMessage(DataFrameListProto)

AttributesProto = _reflection.GeneratedProtocolMessageType('AttributesProto', (_message.Message,), dict(

  AttributesEntry=_reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), dict(
    DESCRIPTOR=_ATTRIBUTESPROTO_ATTRIBUTESENTRY,
    __module__='queueservice_pb2'
    # @@protoc_insertion_point(class_scope:streaming.AttributesProto.AttributesEntry)
  ))
  ,
  DESCRIPTOR=_ATTRIBUTESPROTO,
  __module__='queueservice_pb2'
  # @@protoc_insertion_point(class_scope:streaming.AttributesProto)
))
_sym_db.RegisterMessage(AttributesProto)
_sym_db.RegisterMessage(AttributesProto.AttributesEntry)

DESCRIPTOR._options = None
_DATAFRAMEPROTO_TAGSENTRY._options = None
_ATTRIBUTESPROTO_ATTRIBUTESENTRY._options = None
# @@protoc_insertion_point(module_scope)
